@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-09-25'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2016-10-19'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -108,6 +108,8 @@ sub _process_scenario_module {
 
     my ($self, $document, $input, $package) = @_;
 
+    my $zilla = $input->{zilla};
+
     my $filename = $input->{filename};
 
     # XXX handle dynamically generated module (if there is such thing in the
@@ -217,7 +219,7 @@ sub _process_scenario_module {
         my $i = -1;
         for my $bench (@$sample_benches) {
             $i++;
-            $self->log(["Running benchmark with args %s", $bench->{args}]);
+            $self->log(["Running benchmark of scenario $scenario_name with args %s", $bench->{args}]);
             my $bench_res = Bencher::Backend::bencher(
                 action => 'bench',
                 scenario_module => $scenario_name,
@@ -262,7 +264,7 @@ sub _process_scenario_module {
         } # for sample_benches
 
         if ($self->bench_startup && @modules && !$scenario->{module_startup}) {
-            $self->log(["Running module_startup benchmark"]);
+            $self->log(["Running module_startup benchmark of scenario $scenario_name"]);
             my $bench_res2 = Bencher::Backend::bencher(
                 action => 'bench',
                 module_startup => 1,
@@ -395,6 +397,45 @@ sub _process_scenario_module {
             });
     }
 
+    # create Bencher::ScenarioR::* modules
+    {
+        require Data::Dump;
+        require Dist::Zilla::File::InMemory;
+        my $rname = $input->{filename}; $rname =~ s!Scenario/!ScenarioR/!;
+        my $rpkg = "Bencher::ScenarioR::$scenario_name";
+        my $file = Dist::Zilla::File::InMemory->new(
+            name => $rname,
+            content => join(
+                "",
+                "package $rpkg;\n",
+                "\n",
+
+                #"# DATE\n",
+                #"# VERSION\n",
+                "our \$VERSION = ", dmp($zilla->version), "; # VERSION\n", # workaround for being late to add file
+
+                "\n",
+
+                "our \$results = ", Data::Dump::dump(\@bench_res), ";\n",
+                "\n",
+
+                "1;\n",
+                "# ABSTRACT: $scenario->{summary}\n",
+                "\n",
+
+                "=head1 DESCRIPTION\n\n",
+                "This module is automatically generated by ".__PACKAGE__." during distribution build.\n\n",
+                "A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.\n\n",
+            ),
+        );
+        my @caller = caller();
+        $file->_set_added_by(
+            sprintf("%s (%s line %s)", __PACKAGE__, __PACKAGE__, __LINE__),
+        );
+        push @{ $zilla->files }, $file;
+        $self->log(["Creating file '%s'", $rname]);
+    }
+
     $self->log(["Generated POD for '%s'", $filename]);
 }
 
@@ -496,7 +537,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.20 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-09-25.
+This document describes version 0.21 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-10-19.
 
 =head1 SYNOPSIS
 
@@ -527,6 +568,16 @@ run and shown.
 
 =item * Add a Benchmarked Modules section containing list of benchmarked modules (if any) from the scenario and their versions
 
+=item * Create lib/Bencher/ScenarioR/* module files that contain sample benchmark result data
+
+These module files contain the raw data, while the Sample Benchmark Results POD
+section of the scenario module contains the formatted result. The raw data might
+be useful later. For example I'm thinking of adding a utility later, perhaps in
+the form of an L<lcpan> subcommand, that can guess whether a module is
+relatively fast or slow (compared to similar implementations, which are other
+participants on benchmark scenarios). The utility can then suggest faster
+alternatives.
+
 =back
 
 For each C<lib/Bencher/Scenario/*> module files:
